==> openx-2.5.69-beta.tar.bz2: openx-2.5.69-beta/lib/max/language/ja/report.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: report.lang.php 21310 2008-06-12 11:12:19Z david.keen@openx.org $
*/

$GLOBALS['strAdvertiserCampaignHistoryReport'] 					= 'キャンペーン状況報告書';
$GLOBALS['strAdvertiserCampaignHistoryDescription'] 			= '広告主用の日別キャンペーン状況報告書です。';
$GLOBALS['strAdvertiserHistoryReport'] 							= '広告配信状況告書';
$GLOBALS['strAdvertiserHistoryDescription'] 					= "広告主用の日別配信状況報告書です。";
$GLOBALS['strAdvertiserKeywordHistoryReport'] 					= 'キーワードキャンペーン状況報告書';
$GLOBALS['strAdvertiserKeywordHistoryDescription'] 				= "広告主用のキャンペーン（コンバージョントラッキング含む）キーワード別活動状況報告書です。";
$GLOBALS['strAdvertiserTrackerHistoryReport'] 					= 'トラッキング状況報告書';
$GLOBALS['strAdvertiserTrackerHistoryDescription'] 				= '広告主用のコンバージョン追跡活動状況報告書です。';
$GLOBALS['strAdvertiserZoneAnalysisReport'] 					= 'ゾーン明細報告書';
$GLOBALS['strAdvertiserZoneAnalysisDescription'] 				= '広告主用のサイト別ゾーン別キャンペーン明細報告書です。';
$GLOBALS['strAdvertiserDayOfWeekAnalysisReport'] 				= '曜日別明細報告書';
$GLOBALS['strAdvertiserDayOfWeekAnalysisDescription'] 			= '広告主用のキャンペーンの曜日別明細報告書です。';
$GLOBALS['strAdvertiserHourOfDayAnalysisReport'] 				= '時間帯別明細報告書';
$GLOBALS['strAdvertiserHourOfDayAnalysisDescription'] 			= '広告主用のキャンペーンの時間帯別明細報告書です。';
$GLOBALS['strAdvertiserCreativeSummaryReport'] 					= 'クリエイティブ概要報告書';
$GLOBALS['strAdvertiserCreativeSummaryDescription'] 			= '広告主用のキャンペーンのクリエイティブ別概要報告書です。';
$GLOBALS['strAdvertiserDailyViewsAnalysisReport'] 				= 'デイリービュー明細報告書';
$GLOBALS['strAdvertiserDailyViewsAnalysisDescription'] 			= '広告主用のデイリービュー明細報告書です。';
$GLOBALS['strAdvertiserCampaignSummaryReport'] 					= 'キャンペーン概要報告書';
$GLOBALS['strAdvertiserCampaignSummaryDescription'] 			= '広告主用のキャンペーン別概要報告書です。';
$GLOBALS['strAdvertiserCampaignAnalysisReport'] 				= 'サイト別キャンペーン明細報告書';
$GLOBALS['strAdvertiserCampaignAnalysisDescription'] 			= '広告主用のキャンペーンのサイト別明細報告書です。';
$GLOBALS['strAdvertiserConversionTrackingAnalysisReport'] 		= 'コンバージョン追跡明細報告書';
$GLOBALS['strAdvertiserConversionTrackingAnalysisDescription'] 	= '広告主用のコンバージョン追跡に関する明細報告書です。';

$GLOBALS['strPublisherAdvertisingSummaryReport'] 				= 'Webサイト総括報告書';
$GLOBALS['strPublisherAdvertisingSummaryDescription'] 			= 'サイトオーナー用の配信状況総括報告書です。';
$GLOBALS['strPublisherBannerTypeAnalysisReport'] 				= 'バナータイプ別明細報告書';
$GLOBALS['strPublisherBannerTypeAnalysisDescription'] 			= 'サイトオーナー用のキャンペーンのバナータイプ別明細報告書です。';
$GLOBALS['strPublisherBannerAnalysisReport'] 					= 'バナー別明細報告書';
$GLOBALS['strPublisherBannerAnalysisDescription'] 				= 'サイトオーナー用のキャンペーンバナー別明細報告書です。';
$GLOBALS['strPublisherCampaignAnalysisReport'] 					= 'キャンペーン別明細報告書';
$GLOBALS['strPublisherCampaignAnalysisDescription'] 			= 'サイトオーナー用のキャンペーンサイト別明細報告書です。';
$GLOBALS['strPublisherDayOfWeekAnalysisReport'] 				= '曜日別明細報告書';
$GLOBALS['strPublisherDayOfWeekAnalysisDescription'] 			= 'サイトオーナー用のキャンペーン曜日別明細報告書です。';
$GLOBALS['strPublisherHourOfDayAnalysisReport'] 				= '時間帯別明細報告書';
$GLOBALS['strPublisherHourOfDayAnalysisDescription'] 			= 'サイトオーナー用のキャンペーン時間帯別明細報告書です。';
$GLOBALS['strPublisherRequestViewsAnalysisReport'] 				= 'リクエスト/ビュー別明細報告書';
$GLOBALS['strPublisherRequestViewsAnalysisDescription'] 		= 'サイトオーナー用のキャンペーンリクエスト／ビュー別明細報告書です。';
$GLOBALS['strPublisherZoneAnalysisReport'] 						= 'ゾーン別明細報告書';
$GLOBALS['strPublisherZoneAnalysisDescription'] 				= 'サイトオーナー用のキャンペーンゾーン別明細報告書です。';
$GLOBALS['strPublisherHistoryReport'] 							= 'Webサイト配信状況報告書';
$GLOBALS['strPublisherHistoryDescription'] 						= 'サイトオーナー用のWebサイト配信状況報告書です。';
$GLOBALS['strPublisherZoneHistoryReport'] 						= 'ゾーン別活動概要報告書';
$GLOBALS['strPublisherZoneHistoryDescription'] 					= 'サイトオーナー用のゾーン別活動概要報告書です。';
$GLOBALS['strPublisherConversionTrackingAnalysisReport'] 		= 'コンバージョン追跡明細報告書';
$GLOBALS['strPublisherConversionTrackingAnalysisDescription'] 	= 'サイトオーナー用のコンバージョン追跡明細報告書です。';

$GLOBALS['strAgencyCampaignDeliveryReport'] 					= 'キャンペーン配信状況報告書';
$GLOBALS['strAgencyCampaignDeliveryDescription'] 				= "指定日のキャンペーンのターゲット到達状況を含む代理店用キャンペーントラヒックレポートです。";
$GLOBALS['strAgencyCampaignUnderdeliveryReport'] 				= 'キャンペーン未配信状況報告書';
$GLOBALS['strAgencyCampaignUnderdeliveryDescription'] 			= '代理店用キャンペーン未配信状況報告書です。';
$GLOBALS['strAgencyHistoryReport'] 								= '日別配信状況報告書';
$GLOBALS['strAgencyHistoryDescription']  						= '代理店用日別配信状況報告書です。';

$GLOBALS['strCampaignPredictedFullDeliveryMessage']  			= 'トラッキング追跡中';

$GLOBALS['strStatsAnalysisReport']  							= '明細報告書の統計';


?>

==> openx-2.7.27-beta.tar.bz2: openx-2.7.27-beta/lib/max/language/ja/report.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.7                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: report.lang.php 29689 2008-12-03 16:30:29Z andrew.hill $
*/

$GLOBALS['strAdvertiserCampaignHistoryReport'] 					= 'キャンペーン状況報告書';
$GLOBALS['strAdvertiserCampaignHistoryDescription'] 			= '広告主用の日別キャンペーン状況報告書です。';
$GLOBALS['strAdvertiserHistoryReport'] 							= '広告配信状況告書';
$GLOBALS['strAdvertiserHistoryDescription'] 					= "広告主用の日別配信状況報告書です。";
$GLOBALS['strAdvertiserKeywordHistoryReport'] 					= 'キーワードキャンペーン状況報告書';
$GLOBALS['strAdvertiserKeywordHistoryDescription'] 				= "広告主用のキャンペーン（コンバージョントラッキング含む）キーワード別活動状況報告書です。";
$GLOBALS['strAdvertiserTrackerHistoryReport'] 					= 'トラッキング状況報告書';
$GLOBALS['strAdvertiserTrackerHistoryDescription'] 				= '広告主用のコンバージョン追跡活動状況報告書です。';
$GLOBALS['strAdvertiserZoneAnalysisReport'] 					= 'ゾーン明細報告書';
$GLOBALS['strAdvertiserZoneAnalysisDescription'] 				= '広告主用のサイト別ゾーン別キャンペーン明細報告書です。';
$GLOBALS['strAdvertiserDayOfWeekAnalysisReport'] 				= '曜日別明細報告書';
$GLOBALS['strAdvertiserDayOfWeekAnalysisDescription'] 			= '広告主用のキャンペーンの曜日別明細報告書です。';
$GLOBALS['strAdvertiserHourOfDayAnalysisReport'] 				= '時間帯別明細報告書';
$GLOBALS['strAdvertiserHourOfDayAnalysisDescription'] 			= '広告主用のキャンペーンの時間帯別明細報告書です。';
$GLOBALS['strAdvertiserCreativeSummaryReport'] 					= 'クリエイティブ概要報告書';
$GLOBALS['strAdvertiserCreativeSummaryDescription'] 			= '広告主用のキャンペーンのクリエイティブ別概要報告書です。';
$GLOBALS['strAdvertiserDailyViewsAnalysisReport'] 				= 'デイリービュー明細報告書';
$GLOBALS['strAdvertiserDailyViewsAnalysisDescription'] 			= '広告主用のデイリービュー明細報告書です。';
$GLOBALS['strAdvertiserCampaignSummaryReport'] 					= 'キャンペーン概要報告書';
$GLOBALS['strAdvertiserCampaignSummaryDescription'] 			= '広告主用のキャンペーン別概要報告書です。';
$GLOBALS['strAdvertiserCampaignAnalysisReport'] 				= 'サイト別キャンペーン明細報告書';
$GLOBALS['strAdvertiserCampaignAnalysisDescription'] 			= '広告主用のキャンペーンのサイト別明細報告書です。';
$GLOBALS['strAdvertiserConversionTrackingAnalysisReport'] 		= 'コンバージョン追跡明細報告書';
$GLOBALS['strAdvertiserConversionTrackingAnalysisDescription'] 	= '広告主用のコンバージョン追跡に関する明細報告書です。';

$GLOBALS['strPublisherAdvertisingSummaryReport'] 				= 'Webサイト総括報告書';
$GLOBALS['strPublisherAdvertisingSummaryDescription'] 			= 'サイトオーナー用の配信状況総括報告書です。';
$GLOBALS['strPublisherBannerTypeAnalysisReport'] 				= 'バナータイプ別明細報告書';
$GLOBALS['strPublisherBannerTypeAnalysisDescription'] 			= 'サイトオーナー用のキャンペーンのバナータイプ別明細報告書です。';
$GLOBALS['strPublisherBannerAnalysisReport'] 					= 'バナー別明細報告書';
$GLOBALS['strPublisherBannerAnalysisDescription'] 				= 'サイトオーナー用のキャンペーンバナー別明細報告書です。';
$GLOBALS['strPublisherCampaignAnalysisReport'] 					= 'キャンペーン別明細報告書';
$GLOBALS['strPublisherCampaignAnalysisDescription'] 			= 'サイトオーナー用のキャンペーンサイト別明細報告書です。';
$GLOBALS['strPublisherDayOfWeekAnalysisReport'] 				= '曜日別明細報告書';
$GLOBALS['strPublisherDayOfWeekAnalysisDescription'] 			= 'サイトオーナー用のキャンペーン曜日別明細報告書です。';
$GLOBALS['strPublisherHourOfDayAnalysisReport'] 				= '時間帯別明細報告書';
$GLOBALS['strPublisherHourOfDayAnalysisDescription'] 			= 'サイトオーナー用のキャンペーン時間帯別明細報告書です。';
$GLOBALS['strPublisherRequestViewsAnalysisReport'] 				= 'リクエスト/ビュー別明細報告書';
$GLOBALS['strPublisherRequestViewsAnalysisDescription'] 		= 'サイトオーナー用のキャンペーンリクエスト／ビュー別明細報告書です。';
$GLOBALS['strPublisherZoneAnalysisReport'] 						= 'ゾーン別明細報告書';
$GLOBALS['strPublisherZoneAnalysisDescription'] 				= 'サイトオーナー用のキャンペーンゾーン別明細報告書です。';
$GLOBALS['strPublisherHistoryReport'] 							= 'Webサイト配信状況報告書';
$GLOBALS['strPublisherHistoryDescription'] 						= '広告主用の、Webサイトの流通レポートです';
$GLOBALS['strPublisherZoneHistoryReport'] 						= 'ゾーン別活動概要報告書';
$GLOBALS['strPublisherZoneHistoryDescription'] 					= '広告主用の、Webサイト及び広告枠の流通レポートです';
$GLOBALS['strPublisherConversionTrackingAnalysisReport'] 		= 'コンバージョン追跡明細報告書';
$GLOBALS['strPublisherConversionTrackingAnalysisDescription'] 	= 'このレポートには特定サイト（またはアフィリエイト）に関する全てのコンバージョン内容が表示されています';

$GLOBALS['strAgencyCampaignDeliveryReport'] 					= 'キャンペーン配信状況報告書';
$GLOBALS['strAgencyCampaignDeliveryDescription'] 				= "指定日のキャンペーンのターゲット到達状況を含む代理店用キャンペーントラヒックレポートです。";
$GLOBALS['strAgencyCampaignUnderdeliveryReport'] 				= 'キャンペーン未配信状況報告書';
$GLOBALS['strAgencyCampaignUnderdeliveryDescription'] 			= '代理店用キャンペーン未配信状況報告書です。';
$GLOBALS['strAgencyHistoryReport'] 								= '日別配信状況報告書';
$GLOBALS['strAgencyHistoryDescription']  						= '代理店用日別配信状況報告書です。';

$GLOBALS['strCampaignPredictedFullDeliveryMessage']  			= 'トラッキング追跡中';

$GLOBALS['strStatsAnalysisReport']  							= '明細報告書の統計';


?>
